==> open-xchange-imageconverter-server_7.10.1.orig.tar.bz2: open-xchange-imageconverter-server-7.10.1/com.openexchange.fileitem/src/com/openexchange/fileitem/impl/FileStoreData.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.fileitem.impl;

import java.io.Serializable;

/**
 * {@link FileStoreData}
 *
 * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
 * @since v7.10.0
 */
public class FileStoreData implements Serializable {

    /**
     * serialVersionUID
     */
    private static final long serialVersionUID = 1181641698407844928L;

    /**
     * Initializes a new {@link FileStoreData}.
     */
    public FileStoreData(final int fileStoreNumber, final String fileStoreId) {
        super();

        m_fileStoreNumber = fileStoreNumber;
        m_fileStoreId = fileStoreId;
    }

    @Override
    public String toString() {
        return new StringBuilder("FileStoreData").
            append(" [").
            append("fileStoreNumber: ").append(m_fileStoreNumber).
            append(" , fileStoreId: ").append(m_fileStoreId).
            append(']').toString();
    }

    /**
     * @return
     */
    boolean isValid() {
        return (FileItemUtils.isValid(m_fileStoreId) && (m_fileStoreNumber > 0));
    }

    /**
     * @return
     */
    boolean isInvalid() {
        return (FileItemUtils.isInvalid(m_fileStoreId) || (m_fileStoreNumber < 1));
    }

    /**
     * @return
     */
    int getFileStoreNumber() {
        return m_fileStoreNumber;
    }

    /**
     * @return
     */
    String getFileStoreId() {
        return m_fileStoreId;
    }

    // - Members ---------------------------------------------------------------

    private int m_fileStoreNumber = -1;

    private String m_fileStoreId = null;
}

==> open-xchange-imageconverter-server_7.10.4.orig.tar.bz2: open-xchange-imageconverter-server-7.10.4/com.openexchange.fileitem/src/com/openexchange/fileitem/impl/FileStoreData.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.fileitem.impl;

import java.io.Serializable;

/**
 * {@link FileStoreData}
 *
 * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
 * @since v7.10.0
 */
public class FileStoreData implements Serializable {

    /**
     * serialVersionUID
     */
    private static final long serialVersionUID = 1181641698407844928L;

    /**
     * Initializes a new {@link FileStoreData}.
     */
    public FileStoreData(final int fileStoreNumber, final String fileStoreId) {
        super();

        m_fileStoreNumber = fileStoreNumber;
        m_fileStoreId = fileStoreId;
    }

    @Override
    public String toString() {
        return new StringBuilder(256).
            append("FileStoreData").
            append(" [").
            append("fileStoreNumber: ").append(m_fileStoreNumber).
            append(" , fileStoreId: ").append(m_fileStoreId).
            append(']').toString();
    }

    /**
     * @return
     */
    boolean isValid() {
        return (FileItemUtils.isValid(m_fileStoreId) && (m_fileStoreNumber > 0));
    }

    /**
     * @return
     */
    boolean isInvalid() {
        return (FileItemUtils.isInvalid(m_fileStoreId) || (m_fileStoreNumber < 1));
    }

    /**
     * @return
     */
    int getFileStoreNumber() {
        return m_fileStoreNumber;
    }

    /**
     * @return
     */
    String getFileStoreId() {
        return m_fileStoreId;
    }

    // - Members ---------------------------------------------------------------

    private int m_fileStoreNumber = -1;

    private String m_fileStoreId = null;
}
